Filter

Struct Filter 

pub struct Filter {
Show 32 fields pub device_vendor: Option<String>, pub device_name: Option<String>, pub processor_name: Option<String>, pub device_core: Option<String>, pub fpu: Option<String>, pub mpu: Option<String>, pub trustzone: Option<String>, pub secure: Option<String>, pub dsp: Option<String>, pub mve: Option<String>, pub pacbti: Option<String>, pub endian: Option<String>, pub component_vendor: Option<String>, pub bundle: Option<String>, pub class: Option<String>, pub group: Option<String>, pub sub: Option<String>, pub variant: Option<String>, pub version: Option<String>, pub api_version: Option<String>, pub board_vendor: Option<String>, pub board_name: Option<String>, pub board_revision: Option<String>, pub part_vendor: Option<String>, pub part_name: Option<String>, pub compiler: Option<String>, pub compiler_options: Option<String>, pub compiler_output: Option<String>, pub condition: Option<String>, pub d_family: Option<String>, pub d_sub_family: Option<String>, pub d_variant: Option<String>,
}
Represents the shared filter attributes used by <accept>, <require>, and <deny> elements

All attributes are optional; at least one must be set in a valid filter.

Fields

device_vendor: Option<String>

Device vendor (e.g. ARM:82, STMicroelectronics:13)

device_name: Option<String>

Device name; supports wildcards *, ?, [abc]

processor_name: Option<String>

Processor name for multi-core devices

device_core: Option<String>

Processor core (e.g. Cortex-M0, Cortex-M4)

fpu: Option<String>

Floating-point unit type

mpu: Option<String>

Memory protection unit presence

trustzone: Option<String>

TrustZone support

secure: Option<String>

Secure state support

dsp: Option<String>

DSP instruction set support

mve: Option<String>

M-Profile Vector Extension (Helium) support

pacbti: Option<String>

Pointer Authentication and Branch Target Identification support

endian: Option<String>

Byte endianness (e.g. Little-endian, Big-endian)

component_vendor: Option<String>

Component vendor

bundle: Option<String>

Component bundle name

class: Option<String>

Component class

group: Option<String>

Component group

sub: Option<String>

Component sub-group

variant: Option<String>

Component variant

version: Option<String>

Component version range

api_version: Option<String>

API version range

board_vendor: Option<String>

Board vendor

board_name: Option<String>

Board name

board_revision: Option<String>

Board revision

part_vendor: Option<String>

Hardware part vendor

part_name: Option<String>

Hardware part name

compiler: Option<String>

Compiler toolchain (e.g. GCC, ARMCC, IAR)

compiler_options: Option<String>

Compiler options or mode (e.g. AC5, AC6)

compiler_output: Option<String>

Compiler output type (e.g. exe, lib)

condition: Option<String>

References another condition by its id; this filter is true only if that condition is true

d_family: Option<String>

Deprecated since v1.5; use device_name with the family prefix instead; see pdsc_conditions_pg

d_sub_family: Option<String>

Deprecated since v1.5; use DsubFamily

d_variant: Option<String>

Deprecated since v1.5; use Dvariant