pub enum Expression {
Normal(String),
Conditional(Box<Conditional>),
FunctionCall(Box<DebugFunction>),
}Expand description
A variable representing a PDSC Expression
Variants
Normal(String)
An arithmetic, bitwise, or comparison expression, e.g. 2 + 2, reg & 0xFF, x == 1, or a bare variable reference
Conditional(Box<Conditional>)
An expression representing an inline if statement, e.g. (x < y) ? a : b
Note
The parser currently does not handle nested conditionals, e.g. (x < y) ? ( (a < b) ? c : d ) : e
I hope noone has written a PDSC file which does this, if so this can be implemented.
FunctionCall(Box<DebugFunction>)
A call to a predefined PDSC debug access function,
e.g. Read32(0x40000000) or Sequence("ResetAndHalt")