pub struct Algorithm {
pub name: String,
pub start: Option<String>,
pub size: Option<String>,
pub ram_start: Option<String>,
pub ram_size: Option<String>,
pub default: Option<bool>,
pub style: Option<String>,
pub pname: Option<String>,
pub device_index: Option<String>,
pub parameter: Option<String>,
pub endian: String,
}Expand description
Represents a PDSC algorithm element
Fields
name: StringPath to the flash algorithm file (.FLM)
start: Option<String>Start address of the flash region (hex string, e.g. "0x00000000")
size: Option<String>Size of the flash region in bytes (hex string, e.g. "0x00010000")
ram_start: Option<String>Start address of the RAM buffer used by the algorithm
ram_size: Option<String>Size of the RAM buffer in bytes
default: Option<bool>If true, this is the default algorithm for the device
style: Option<String>Algorithm style (Keil or IAR)
pname: Option<String>Processor instance name this algorithm applies to
device_index: Option<String>Index of the mounted device this algorithm applies to (only used by board descriptions with multiple mounted devices)
parameter: Option<String>Parameter passed on algorithm invocation
endian: StringEndianness of the algorithm; valid values: DendianEnum; defaults to "Little-endian"