pub struct Debugvars {
pub configfile: Option<String>,
pub version: Option<String>,
pub content: String,
pub parsed_debugvars: Option<HashMap<String, u64>>,
}Expand description
Represents PDSC Debugvars
Fields
configfile: Option<String>The relative path to the configuration file containing debugvars
version: Option<String>Debugvars version
content: StringDebugvars variable declarations
parsed_debugvars: Option<HashMap<String, u64>>Parsed debugvars, initially None, generated by Debugvars::parse_debugvars
Implementations
Sourceimpl Debugvars
impl Debugvars
Sourcepub fn parse_single_debugvar(
line: &str,
) -> Result<(String, u64), FamilyParseError>
pub fn parse_single_debugvar( line: &str, ) -> Result<(String, u64), FamilyParseError>
Parses a single variable declaration entry.
Returns Ok((name, value)) for a valid __var name = value; declaration.
Errors
Returns FamilyParseError::MalformedDebugvar if the line is not a valid __var declaration.
Sourcepub fn parse_debugvars_content(&self) -> HashMap<String, u64>
pub fn parse_debugvars_content(&self) -> HashMap<String, u64>
Parses the debugvars content and returns a hashmap with the variable name as the key and the value as the value
Sourcepub fn parse_debugvars(&mut self)
pub fn parse_debugvars(&mut self)
Performs the parsing and stores values in Self::parsed_debugvars