SequenceBlock

Struct SequenceBlock 

pub struct SequenceBlock {
    pub atomic: Option<bool>,
    pub info: Option<String>,
    pub content: String,
    pub statements: Vec<Statement>,
}
Represents a PDSC Block Sequence

Fields

atomic: Option<bool>

If Some(true) the block must be executed atomically, see the description on CMSIS Pack website.

info: Option<String>

Decsriptive text, e.g. for diagnostics

content: String

Sequence block content

statements: Vec<Statement>

Statements resulting from the parsing of Self::content

Implementations

Source

impl SequenceBlock

pub fn parse_statements_content(&self) -> Result<Vec<Statement>, Error>

Parses Self::content into a list of Statements

Errors

Returns crate::Error::Debug if any statement line fails to parse.

pub fn parse_statements(&mut self) -> Result<(), Error>

Parses the block content and stores the result in Self::statements

Errors

Returns crate::Error::Debug if any statement line fails to parse; see Self::parse_statements_content.