Sequences

Struct Sequences 

pub struct Sequences<'a> {
    pub trace_setup: Option<TraceSetup>,
    pub raw_nodes: Vec<RawNode<'a>>,
    pub sequences: Vec<Sequence>,
}
Represents PDSC sequences

Fields

trace_setup: Option<TraceSetup>

Trace setup configuration

raw_nodes: Vec<RawNode<'a>>

Raw XML nodes representing debug sequences

These are stored as RawNode due to serde_roxmltree not supporting decoding elements as a vector of enums and we neet do be able to preresent both control and block elements with their order perserved.

sequences: Vec<Sequence>

Debug Sequences

Implementations

Source

impl Sequences<'_>

pub fn parse_raw_nodes_content(&self) -> Result<Vec<Sequence>, Error>

Iterates through the raw nodes and parses the sequences

Errors

Returns crate::Error::Family if any raw sequence node fails to parse.

pub fn parse_sequences(&mut self) -> Result<(), Error>

Parses the raw XML Sequence nodes and stores the parsed sequences in Self::sequences

Errors

Returns crate::Error::Family if any sequence node fails to parse; see Self::parse_raw_nodes_content.