pub struct Web {
pub url: String,
pub arguments: Vec<WebArgument>,
}Expand description
Represents the PDSC web element
Defines a web service invocation of the generator tool.
Fields
url: StringURL of the web service endpoint to invoke
arguments: Vec<WebArgument>Query parameters or arguments passed to the web service