pub struct Changelog {
pub id: String,
pub name: String,
pub default: Option<bool>,
pub changelog_type: Option<String>,
}Expand description
Represents the PDSC Changelog element
Fields
id: StringChangelog identifier string, must be uniuqe within the PDSC file
name: StringA path relative to the PDSC file and the filename of the changelog file
default: Option<bool>If true this changelog is associated with all APIs and components that do not explicitly reference another changelog; xs:boolean ("true" / "false")
changelog_type: Option<String>File type of the changelog file; text/plain;charset=UTF-8 is assumed if not specified