pub struct LicenseSet {
pub id: String,
pub default: Option<bool>,
pub gating: Option<bool>,
pub license: Vec<License>,
}Expand description
Represents the PDSC LicenseSetsType
Fields
id: StringLicense set identifier string, must be uniuqe in the PDSC file
default: Option<bool>If set to true this license set is associated with all content, not explicitly referencing another license set
gating: Option<bool>If set to true this license set is required to be accepted by the user before installation starts.
license: Vec<License>Description of the license file refereneces