pub struct Conditional {
pub condition: Expression,
pub true_value: Expression,
pub false_value: Expression,
}Expand description
An expression representing an inline if statement, e.g. (x < y) ? a : b
Note
The parser currently does not handle nested conditionals, e.g. (x < y) ? ( (a < b) ? c : d ) : e
I hope noone has written a PDSC file which does this, if so this can be implemented.
Fields
condition: ExpressionThe conditional part, (x < y) ? a : b -> x < y
true_value: ExpressionThe value when the conditional evaluates to true, (x < y) ? a : b -> a
false_value: ExpressionThe value when the conditional evaluates to false, (x < y) ? a : b -> b